# Part of Odoo. See LICENSE file for full copyright and licensing details.
from . import template_fi
from . import account_journal
from . import account_move
